import _Object$keys from 'babel-runtime/core-js/object/keys';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _defineProperty from 'babel-runtime/helpers/defineProperty';
import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import cx from 'classnames';
import Box from './Box';
import theme from './theme';
var majorScale = theme.majorScale,
    colors = theme.colors,
    rawColors = theme.rawColors;


var intentStateStyle = function intentStateStyle(intentState) {
  return _extends({
    backgroundColor: intentState.backgroundColor,
    color: intentState.textColor
  }, intentState.border ? {
    border: intentState.border
  } : {}, intentState.boxShadow ? {
    boxShadow: intentState.boxShadow
  } : {});
};

var intentStyle = function intentStyle(intent) {
  var _extends2;

  return _extends({}, intentStateStyle(intent.default), (_extends2 = {
    '&:hover': _extends({}, intentStateStyle(intent.hover)),
    '&:focus': _extends({}, intentStateStyle(intent.focus))
  }, _defineProperty(_extends2, '&:active, &.' + theme.activeClassName, _extends({}, intentStateStyle(intent.active))), _defineProperty(_extends2, '&:disabled, &.' + theme.activeClassName + ':disabled', {
    cursor: 'default',
    backgroundColor: colors.backgroundTint2,
    color: rawColors.grey300,
    border: 'none'
  }), _extends2));
};

var getStyle = function getStyle(_ref) {
  var primary = _ref.primary,
      secondary = _ref.secondary,
      danger = _ref.danger;

  if (primary) return css(intentStyle(theme.intent['primary']));
  if (danger) return css(intentStyle(theme.intent['danger']));
  if (secondary) return css(intentStyle(theme.intent['secondary'])); /* default */
  return '';
};

var baseStyles = css({
  textTransform: 'capitalize',
  border: 0,
  fontWeight: 400,
  textDecoration: 'none',
  transition: theme.animationDuration.faster,
  transitionProperty: 'background-color, color, box-shadow, opacity',
  cursor: 'pointer',
  whiteSpace: 'nowrap',
  userSelect: 'none',
  verticalAlign: 'middle',
  '&:active, &:focus': {
    outline: 'none'
  }
});

function useControlSizes(_ref2) {
  var size = _ref2.size,
      props = _objectWithoutProperties(_ref2, ['size']);

  var sizes = theme.controlSizes[size];
  var paddingX = {
    small: majorScale(2),
    default: majorScale(3)
  };

  return _extends({
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: paddingX[size]
  }, props);
}

var parseProps = function parseProps(_ref3) {
  var className = _ref3.className,
      primary = _ref3.primary,
      secondary = _ref3.secondary,
      danger = _ref3.danger,
      props = _objectWithoutProperties(_ref3, ['className', 'primary', 'secondary', 'danger']);

  return _extends({
    className: cx('' + baseStyles, '' + getStyle({ primary: primary, secondary: secondary, danger: danger }), className)
  }, props);
};

var Button = function Button(props) {
  return React.createElement(Box, parseProps(useControlSizes(props)));
};

Button.propTypes = _extends({}, Box.propTypes, {
  primary: PropTypes.bool,
  secondary: PropTypes.bool,
  danger: PropTypes.bool,
  size: PropTypes.oneOf(_Object$keys(theme.controlSizes))
});

Button.defaultProps = {
  is: 'button',
  display: 'inline-flex',
  alignItems: 'center',
  justifyContent: 'center',
  size: 'default',
  secondary: true,
  rounded: true
};

Button.displayName = 'Button';

export default Button;