import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _extends from 'babel-runtime/helpers/extends';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import Box from './Box';
import Overlay from './Overlay';
import CloseIcon from './Close';
import theme from './theme';
import offscreenCss from './utils/offscreenCss';
var majorScale = theme.majorScale,
    minorScale = theme.minorScale,
    borderRadius = theme.borderRadius,
    colors = theme.colors,
    rawColors = theme.rawColors,
    textStyles = theme.textStyles;


var overlayStyles = {
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'center'
};

var mainCss = css({
  position: 'relative',
  maxWidth: majorScale(72),
  border: '1px solid ' + colors.borderColor,
  borderRadius: borderRadius[1],
  background: colors.white,
  animationDuration: theme.animationDuration.fast,
  animationTimingFunction: theme.animationEasing.standard,
  animationFillMode: 'forwards'
});

var titleCss = css(_extends({
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'space-between',
  padding: majorScale(2) + ' ' + majorScale(3),
  borderBottom: '1px solid ' + colors.borderColor
}, textStyles.display3));

var buttonCss = css({
  padding: majorScale(1),
  marginRight: '-' + majorScale(1),
  background: 'none',
  cursor: 'pointer',
  color: rawColors.grey300,
  lineHeight: 0,
  ':hover, :focus': {
    outline: 'none',
    color: rawColors.grey400
  }
});

var openAnimation = css.keyframes('openAnimation', {
  from: {
    transform: 'scale(0.8)',
    opacity: 0
  },
  to: {
    transform: 'scale(1)',
    opacity: 1
  }
});

var closeAnimation = css.keyframes('closeAnimation', {
  from: {
    transform: 'scale(1)',
    opacity: 1
  },
  to: {
    transform: 'scale(0.8)',
    opacity: 0
  }
});

var parseProps = function parseProps(_ref) {
  var className = _ref.className,
      children = _ref.children,
      title = _ref.title,
      isOpen = _ref.isOpen,
      onClose = _ref.onClose,
      props = _objectWithoutProperties(_ref, ['className', 'children', 'title', 'isOpen', 'onClose']);

  return props;
};

var Dialog = function (_Component) {
  _inherits(Dialog, _Component);

  function Dialog(props) {
    _classCallCheck(this, Dialog);

    var _this = _possibleConstructorReturn(this, (Dialog.__proto__ || _Object$getPrototypeOf(Dialog)).call(this));

    _this.state = {
      isMounted: props.isOpen,
      isClosing: false
    };

    _this.handleFadeEnd = _this.handleFadeEnd.bind(_this);
    return _this;
  }

  _createClass(Dialog, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      if (!this.props.isOpen && nextProps.isOpen) {
        this.setState({ isMounted: true, isClosing: false });
      }

      if (this.props.isOpen && !nextProps.isOpen) {
        this.setState({ isMounted: true, isClosing: true });
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          title = _props.title,
          onClose = _props.onClose,
          children = _props.children;
      var _state = this.state,
          isMounted = _state.isMounted,
          isClosing = _state.isClosing;


      if (!isMounted) return null;

      var style = {
        animationName: '' + (isClosing ? closeAnimation : openAnimation)
      };

      return React.createElement(
        Overlay,
        _extends({
          onClick: onClose,
          fadeOut: isClosing,
          onFadeEnd: this.handleFadeEnd
        }, overlayStyles),
        React.createElement(
          Box,
          _extends({}, parseProps(this.props), {
            is: 'section',
            className: '' + mainCss,
            style: style,
            role: 'dialog',
            'aria-label': title
          }),
          React.createElement(
            Box,
            { is: 'h2', className: '' + titleCss },
            title,
            onClose && React.createElement(
              Box,
              { is: 'button', className: '' + buttonCss, onClick: onClose },
              React.createElement(
                'div',
                { className: '' + offscreenCss },
                'Close'
              ),
              React.createElement(CloseIcon, { width: minorScale(3), height: minorScale(3) })
            )
          ),
          React.createElement(
            Box,
            { padding: majorScale(3) },
            children
          )
        )
      );
    }
  }, {
    key: 'handleFadeEnd',
    value: function handleFadeEnd() {
      if (!this.state.isClosing) return;
      this.setState({ isMounted: false, isClosing: false });
    }
  }]);

  return Dialog;
}(Component);

Dialog.propTypes = _extends({}, Box.propTypes, {
  title: PropTypes.node.isRequired,
  isOpen: PropTypes.bool.isRequired,
  children: PropTypes.node.isRequired,
  onClose: PropTypes.func
});

Dialog.defaultProps = {
  isOpen: false
};

Dialog.displayName = 'Dialog';

export default Dialog;