import _Object$keys from 'babel-runtime/core-js/object/keys';
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import cx from 'classnames';
import Box from './Box';
import ExclamationCircle from './ExclamationCircle';
import theme from './theme';
import splitProps from './utils/splitProps';
var minorScale = theme.minorScale,
    majorScale = theme.majorScale,
    controlStateStyles = theme.controlStateStyles,
    textColors = theme.textColors;


var styles = css({
  backgroundColor: controlStateStyles.default.backgroundColor,
  color: controlStateStyles.default.color,
  border: controlStateStyles.default.border,
  transition: controlStateStyles.default.transition,
  '&:focus': {
    border: controlStateStyles.focus.border,
    boxShadow: controlStateStyles.focus.boxShadow
  },
  '&:disabled': {
    cursor: 'not-allowed',
    backgroundColor: controlStateStyles.disabled.backgroundColor,
    color: controlStateStyles.disabled.color,
    border: controlStateStyles.disabled.border
  },
  '&::placeholder': {
    color: textColors.muted
  }
});

function useControlSizes(_ref) {
  var size = _ref.size,
      props = _objectWithoutProperties(_ref, ['size']);

  var sizes = theme.controlSizes[size];

  return _extends({
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: size === 'small' ? minorScale(3) : majorScale(2)
  }, props);
}

var Input = function Input(_ref2) {
  var warning = _ref2.warning,
      className = _ref2.className,
      props = _objectWithoutProperties(_ref2, ['warning', 'className']);

  // Tries to treat this component as a single box
  var _splitProps = splitProps(useControlSizes(props), /margin|width|height|display|flex|alignItems|justifyContent|flexDirection|flexGrow|flexShrink/gi),
      matchedProps = _splitProps.matchedProps,
      unmatchedProps = _splitProps.unmatchedProps;

  return React.createElement(
    Box,
    _extends({ position: 'relative', display: 'flex' }, matchedProps),
    warning ? React.createElement(ExclamationCircle, { position: 'absolute', top: '50%', marginLeft: '-5px', marginTop: '-6px' }) : null,
    React.createElement(Box, _extends({ is: 'input', className: cx('' + styles, className), flex: '1' }, unmatchedProps))
  );
};

Input.propTypes = {
  warning: PropTypes.bool,
  size: PropTypes.oneOf(_Object$keys(theme.controlSizes))
};

Input.defaultProps = {
  rounded: true,
  size: 'default'
};

Input.displayName = 'Input';

export default Input;