import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import Pane from './Pane';
import Text from './Text';
import Link from './Link';
import Box from './Box';
import SegmentLogo from './SegmentLogo';
import theme from './theme';
var minorScale = theme.minorScale,
    majorScale = theme.majorScale;


var NavigationBarLink = function NavigationBarLink(props) {
  return React.createElement(Link, _extends({ primary: false }, css({
    color: theme.rawColors.blue100,
    '&:hover': {
      color: 'white',
      backgroundColor: theme.rawColors.blue800
    },
    '&:active, &.active': {
      color: 'white',
      backgroundColor: theme.rawColors.blue500
    }
  }), props));
};

NavigationBarLink.defaultProps = {
  circle: true,
  textStyle: 'body1',
  paddingX: minorScale(3),
  paddingY: minorScale(1),
  marginX: minorScale(1)
};

var NavigationBarTitle = function NavigationBarTitle(props) {
  return React.createElement(Text, props);
};

NavigationBarTitle.defaultProps = {
  is: 'h1',
  textStyle: 'display3',
  bold: true
};

// paddingTop is somewhat of a hack here, but flex will cause the truncate to fail
var NavigationBarLeftTitle = function NavigationBarLeftTitle(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, ['children']);

  return React.createElement(
    Box,
    { marginLeft: majorScale(2), truncate: true, paddingTop: '1px', paddingLeft: majorScale(2), borderLeft: true, borderColor: 'rgba(255,255,255,0.2)' },
    React.createElement(
      Text,
      _extends({ is: 'span', textStyle: 'body1' }, props),
      children
    )
  );
};

var NavigationBarLogo = function NavigationBarLogo(props) {
  return React.createElement(SegmentLogo, _extends({ marginTop: '-1px', minWidth: '106px', width: '106px' }, props));
};

var NavigationBarPane = function NavigationBarPane(props) {
  return React.createElement(Pane, _extends({ alignItems: 'center', dark: true, display: 'flex' }, props));
};

var NavigationBar = function NavigationBar(_ref2) {
  var logo = _ref2.logo,
      left = _ref2.left,
      right = _ref2.right,
      height = _ref2.height,
      children = _ref2.children,
      props = _objectWithoutProperties(_ref2, ['logo', 'left', 'right', 'height', 'children']);

  var child = void 0;
  if (typeof children === 'string') {
    child = React.createElement(
      NavigationBarTitle,
      null,
      children
    );
  } else {
    child = children;
  }

  var leftChild = void 0;
  if (typeof left === 'string') {
    leftChild = React.createElement(
      NavigationBarLeftTitle,
      null,
      left
    );
  } else {
    leftChild = left;
  }

  return React.createElement(
    NavigationBarPane,
    _extends({ height: height }, props),
    React.createElement(
      Pane,
      { width: '33%', height: '100%', padding: majorScale(2), display: 'flex' },
      logo,
      ' ',
      leftChild
    ),
    React.createElement(
      Pane,
      { flexAuto: true, textAlign: 'center' },
      child
    ),
    React.createElement(
      Pane,
      { width: '33%', textAlign: 'right', padding: minorScale(3) },
      right
    )
  );
};

NavigationBar.propTypes = {
  logo: PropTypes.node,
  left: PropTypes.node,
  right: PropTypes.node,
  children: PropTypes.oneOfType([PropTypes.node, PropTypes.string]),
  height: PropTypes.string
};

NavigationBar.defaultProps = {
  logo: React.createElement(NavigationBarLogo, null),
  height: majorScale(7)
};

export { NavigationBar, NavigationBarLink, NavigationBarTitle };