import _extends from 'babel-runtime/helpers/extends';
import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import theme from './theme';
import Box from './Box';
import Color from 'color';

var transparentBg = Color(theme.rawColors.grey400).alpha(0).rgb().string();
var opaqueBg = Color(theme.rawColors.grey400).alpha(0.8).rgb().string();

var fadeInAnimation = css.keyframes('fadeInAnimation', {
  from: {
    backgroundColor: transparentBg
  },
  to: {
    backgroundColor: opaqueBg
  }
});

var fadeOutAnimation = css.keyframes('fadeOutAnimation', {
  from: {
    backgroundColor: opaqueBg
  },
  to: {
    backgroundColor: transparentBg
  }
});

var mainCss = css({
  position: 'fixed',
  zIndex: 10,
  top: 0,
  right: 0,
  bottom: 0,
  left: 0,
  background: opaqueBg,
  animationDuration: theme.animationDuration.slow,
  animationTimingFunction: theme.animationEasing.standard,
  animationFillMode: 'forwards'
});

var parseProps = function parseProps(_ref) {
  var className = _ref.className,
      fadeOut = _ref.fadeOut,
      onClick = _ref.onClick,
      onFadeEnd = _ref.onFadeEnd,
      props = _objectWithoutProperties(_ref, ['className', 'fadeOut', 'onClick', 'onFadeEnd']);

  return props;
};

var Overlay = function (_Component) {
  _inherits(Overlay, _Component);

  function Overlay() {
    _classCallCheck(this, Overlay);

    var _this = _possibleConstructorReturn(this, (Overlay.__proto__ || _Object$getPrototypeOf(Overlay)).call(this));

    _this.handleClick = _this.handleClick.bind(_this);
    _this.handleAnimationEnd = _this.handleAnimationEnd.bind(_this);
    return _this;
  }

  _createClass(Overlay, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      document.body.style.overflow = 'hidden';
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      document.body.style.overflow = 'initial';
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          fadeOut = _props.fadeOut,
          children = _props.children;

      var style = {
        animationName: '' + (fadeOut ? fadeOutAnimation : fadeInAnimation)
      };

      return React.createElement(
        Box,
        _extends({}, parseProps(this.props), {
          className: '' + mainCss,
          style: style,
          onRef: function onRef(node) {
            return _this2.node = node;
          },
          onClick: this.handleClick,
          onAnimationEnd: this.handleAnimationEnd
        }),
        children
      );
    }
  }, {
    key: 'handleClick',
    value: function handleClick(e) {
      if (this.props.onClick && e.target === this.node) {
        this.props.onClick();
      }
    }
  }, {
    key: 'handleAnimationEnd',
    value: function handleAnimationEnd(e) {
      if (this.props.onFadeEnd && e.target === this.node) {
        this.props.onFadeEnd();
      }
    }
  }]);

  return Overlay;
}(Component);

Overlay.propTypes = _extends({}, Box.propTypes, {
  fadeOut: PropTypes.bool,
  onClick: PropTypes.func,
  onFadeEnd: PropTypes.func
});

Overlay.defaultProps = {
  fadeOut: false
};

Overlay.displayName = 'Overlay';

export default Overlay;