import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import Box from './Box';
import Pane from './Pane';
import Overlay from './Overlay';
import Close from './Close';
import theme from './theme';
var majorScale = theme.majorScale;


var rotate360InAnimation = css.keyframes('rotate360InAnimation', {
  from: {
    transform: 'translateX(100%) rotate(0deg)'
  },
  to: {
    transform: 'translateX(-100%) rotate(-360deg)'
  }
});

var rotate360OutAnimation = css.keyframes('rotate360OutAnimation', {
  from: {
    transform: 'translateX(-100%) rotate(0deg)'
  },
  to: {
    transform: 'translateX(100%) rotate(360deg)'
  }
});

var SheetClose = function SheetClose(_ref) {
  var isClosing = _ref.isClosing,
      props = _objectWithoutProperties(_ref, ['isClosing']);

  return React.createElement(
    Box,
    _extends({}, css({
      cursor: 'pointer',
      transform: 'translateX(-100%)',
      backgroundColor: 'rgba(255, 255, 255, 0.4)',
      transition: 'background-color ' + theme.animationDuration.fast,
      animation: (isClosing ? rotate360OutAnimation : rotate360InAnimation) + ' ' + theme.animationDuration.slow + ' ' + theme.animationEasing.deceleration,
      '&:hover': {
        backgroundColor: 'rgba(255, 255, 255, 0.6)'
      },
      '&:active': {
        backgroundColor: 'rgba(255, 255, 255, 0.4)'
      }
    }), props),
    React.createElement(Close, { fill: '#fff', display: 'block' })
  );
};

SheetClose.defaultProps = {
  position: 'absolute',
  marginLeft: majorScale(-2),
  marginTop: majorScale(2),
  padding: majorScale(1),
  circle: true
};

var slideInAnimation = css.keyframes('slideInAnimation', {
  from: {
    transform: 'translateX(100%)'
  },
  to: {
    transform: 'translateX(0)'
  }
});

var slideOutAnimation = css.keyframes('slideOutAnimation', {
  from: {
    transform: 'translateX(0)'
  },
  to: {
    transform: 'translateX(100%)'
  }
});

var SheetPane = function SheetPane(_ref2) {
  var slideOut = _ref2.slideOut,
      props = _objectWithoutProperties(_ref2, ['slideOut']);

  return React.createElement(Pane, _extends({}, css({
    transform: 'translateZ(0)',
    animation: (slideOut ? slideOutAnimation : slideInAnimation) + ' ' + theme.animationDuration.slow + ' ' + theme.animationEasing.deceleration
  }), props));
};

SheetPane.propTypes = {
  slideOut: PropTypes.bool
};

SheetPane.defaultProps = {
  white: true,
  position: 'absolute',
  shadow: true,
  top: 0,
  right: 0,
  bottom: 0
};

SheetPane.displayName = 'SheetPane';

var Sheet = function (_Component) {
  _inherits(Sheet, _Component);

  function Sheet() {
    _classCallCheck(this, Sheet);

    var _this = _possibleConstructorReturn(this, (Sheet.__proto__ || _Object$getPrototypeOf(Sheet)).call(this));

    _this.handleClose = _this.handleClose.bind(_this);
    _this.handleFadeEnd = _this.handleFadeEnd.bind(_this);

    _this.state = {
      isClosing: false
    };
    return _this;
  }

  _createClass(Sheet, [{
    key: 'handleClose',
    value: function handleClose() {
      this.setState({ isClosing: true });
    }
  }, {
    key: 'handleFadeEnd',
    value: function handleFadeEnd() {
      if (!this.state.isClosing) return;
      if (this.props.onClose) {
        this.props.onClose();
      }
      this.setState({ isClosing: false });
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          isOpen = _props.isOpen,
          children = _props.children;
      var isClosing = this.state.isClosing;

      var divStyle = {
        position: 'absolute',
        left: 0,
        right: 0,
        top: 0,
        bottom: 0,
        overflow: 'auto'
      };
      if (!isOpen) return null;

      return React.createElement(
        Overlay,
        { onClick: this.handleClose, fadeOut: isClosing, onFadeEnd: this.handleFadeEnd },
        React.createElement(
          SheetPane,
          _extends({ slideOut: isClosing }, this.parseProps(this.props)),
          React.createElement(SheetClose, { isClosing: isClosing, onClick: this.handleClose }),
          React.createElement(
            'div',
            { style: divStyle },
            children
          )
        )
      );
    }
  }, {
    key: 'parseProps',
    value: function parseProps(_ref3) {
      var className = _ref3.className,
          children = _ref3.children,
          isOpen = _ref3.isOpen,
          onClose = _ref3.onClose,
          props = _objectWithoutProperties(_ref3, ['className', 'children', 'isOpen', 'onClose']);

      return props;
    }
  }]);

  return Sheet;
}(Component);

Sheet.propTypes = _extends({}, Box.propTypes, {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func
});

Sheet.defaultProps = {
  width: majorScale(85),
  isOpen: true
};

Sheet.displayName = 'Sheet';

export default Sheet;