import React from 'react';
import { storiesOf } from '@storybook/react';
import { App, Pane, theme } from '../components';
import Content from './Content';
var majorScale = theme.majorScale;


export default function contentStory(module) {
  storiesOf('Content', module).add('usage', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { white: true, padding: majorScale(10) },
        React.createElement(
          Content,
          { markdown: true },
          '# Content\n\n***This component is internal only for use in stories.***\n\n---\n\nThe Content component is used for blocks of content. Implements `<Box />`.\n\nStyles semantic elements inside. Think of h1-h6, p, ul, ol etc.\n\n```\n<Content>\n  <h1>Code block example</h1>\n</Content>\n\n<Content markdown>\n{`\n* Make sure there is no whitespace on the left\n* Escape your backticks with a backslash.\n`}\n</Content>\n```\n\nprop | type | description | default\n-----|------|-------------|-------\n`markdown`    | boolean | enables markdown | `undefined`\n`indentLists`   | boolean  | adds left margin to lists | `true`\n`maxLineWidth` | boolean/string  | max-width on paragraphs | `true` which is 40em\n\n## Implemented styles\n\n* headings h1-h6, although h4-h6 are the same\n* paragraphs\n* *emphasis*\n* **strong**\n* [link](example.com)\n* `code`\n* pre block\n* unordered list\n* ordered list\n* line\n\n### Ordered list example\n\n1. Ordered lists\n2. Work too...\n\n### Line example\n\n---\n\n### Code block example\n\n```\n<Content markdown>\n  <h1>Code block example</h1>\n</Content>\n```\n\n### Table example\n\nprop | type | description\n-----|------|------------\n`john`    | boolean | hello\n`doe`   | string  | align-items\n\n\n'
        )
      )
    );
  }).add('with markdown', function () {
    return React.createElement(
      Pane,
      { padding: majorScale(3), clearfix: true },
      React.createElement(
        Content,
        { markdown: true },
        '\n# Content with Markdown\n\nMarkdown is supported by [react-remarkable](https://github.com/acdlite/react-remarkable) .\n\nBe aware if you are entering markdown as a string there is no whitespace on the left.\nOtherwise the parser will think it is a pre block.\n'
      )
    );
  });
}