import React from 'react';
import { storiesOf } from '@storybook/react';
import { theme, App, Pane, Pagination } from '../components';
import Content from './Content';
var majorScale = theme.majorScale;


export default function paginationStory(module) {
  storiesOf('Pagination', module).add('usage', function () {
    return React.createElement(
      App,
      { white: true },
      React.createElement(
        Pane,
        { white: true, padding: majorScale(10) },
        React.createElement(
          Content,
          { markdown: true },
          '\n# Pagination\n\nThe Pagination component is used to provide pagination controls for use with large lists of content.\n\n```\n<Pagination\n  itemName={\'item\'}\n  pageSize={50}\n  onPageSizeChange={() => {}}\n  totalItemCount={100}\n  currentPageNum={0}\n  onCurrentPageNumChange={() => {}}\n  firstPageNum={0}\n  lastPageNum={100}\n/>\n```\n\n'
        ),
        React.createElement(Pagination, {
          itemName: 'item',
          pageSize: 50,
          onPageSizeChange: function onPageSizeChange() {},
          totalItemCount: 100,
          currentPageNum: 0,
          onCurrentPageNumChange: function onCurrentPageNumChange() {},
          firstPageNum: 0,
          lastPageNum: 100
        }),
        React.createElement(
          Content,
          { markdown: true },
          '\nprop | type | description\n-----|------|-------------\n`itemName` | string | the name of the items in paginated list\n`pageSize` | int | the current number of items shown at once\n`onPageSizeChange` | func | callback when a new page size is selected\n`totalItemCount` | int | the total number of items in paginated list\n`currentPageNum` | int | the current page of pagination\n`onCurrentPageNumChange` | func | callback when a new page num is selected\n`firstPageNum` | int | the number that the pagination should start at\n`lastPageNum` | int | the number that the pagination should end at\n`hidePageSizeSelect` | boolean | whether or not the page size select should be hidden\n'
        )
      )
    );
  });
}