'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _glamor = require('glamor');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Pane = require('./Pane');

var _Pane2 = _interopRequireDefault(_Pane);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

var _SuccessAlertIcon = require('./SuccessAlertIcon');

var _SuccessAlertIcon2 = _interopRequireDefault(_SuccessAlertIcon);

var _QuestionAlertIcon = require('./QuestionAlertIcon');

var _QuestionAlertIcon2 = _interopRequireDefault(_QuestionAlertIcon);

var _DangerAlertIcon = require('./DangerAlertIcon');

var _DangerAlertIcon2 = _interopRequireDefault(_DangerAlertIcon);

var _WarningAlertIcon = require('./WarningAlertIcon');

var _WarningAlertIcon2 = _interopRequireDefault(_WarningAlertIcon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var minorScale = _theme2.default.minorScale,
    majorScale = _theme2.default.majorScale;


var getStyle = function getStyle(_ref) {
  var type = _ref.type,
      showTrim = _ref.showTrim;

  var trim = showTrim ? {
    '&:before': {
      content: '""',
      width: minorScale(1),
      height: '100%',
      position: 'absolute',
      top: 0,
      left: 0,
      backgroundColor: _theme2.default.colors[type]
    }
  } : {};

  return (0, _glamor.css)(_extends({
    'boxShadow': _theme2.default.shadows[0] + ', inset 0 0 0 1px ' + _theme2.default.colors.borderColor
  }, trim));
};

var parseProps = function parseProps(_ref2) {
  var className = _ref2.className,
      type = _ref2.type,
      showTrim = _ref2.showTrim,
      props = _objectWithoutProperties(_ref2, ['className', 'type', 'showTrim']);

  return _extends({
    className: (0, _classnames2.default)('' + getStyle({ type: type, showTrim: showTrim }), className)
  }, props);
};

var AlertIcon = function AlertIcon(_ref3) {
  var type = _ref3.type,
      props = _objectWithoutProperties(_ref3, ['type']);

  switch (type) {
    case 'success':
      return _react2.default.createElement(_SuccessAlertIcon2.default, props);
    case 'question':
      return _react2.default.createElement(_QuestionAlertIcon2.default, props);
    case 'warning':
      return _react2.default.createElement(_WarningAlertIcon2.default, props);
    case 'danger':
      return _react2.default.createElement(_DangerAlertIcon2.default, props);
    default:
      return null;
  }
};

AlertIcon.propTypes = _extends({}, _SuccessAlertIcon2.default.propTypes);

AlertIcon.defaultProps = {
  marginTop: minorScale(1),
  marginRight: majorScale(2)
};

var Alert = function Alert(_ref4) {
  var children = _ref4.children,
      showIcon = _ref4.showIcon,
      props = _objectWithoutProperties(_ref4, ['children', 'showIcon']);

  return _react2.default.createElement(
    _Pane2.default,
    parseProps(props),
    showIcon && _react2.default.createElement(AlertIcon, { flexShrink: '0', type: props.type }),
    _react2.default.createElement(
      _Pane2.default,
      null,
      children
    )
  );
};

Alert.propTypes = _extends({}, _Pane2.default.propTypes, {
  type: _propTypes2.default.oneOf(['naked', 'success', 'warning', 'danger', 'question']),
  showIcon: _propTypes2.default.bool,
  showTrim: _propTypes2.default.bool
});

Alert.defaultProps = {
  showIcon: true,
  showTrim: true,
  type: 'naked',
  white: true,
  rounded: true,
  paddingX: majorScale(3),
  paddingY: majorScale(2),
  textStyle: 'body1',
  display: 'flex',
  width: '440px',
  position: 'relative',
  overflow: 'hidden'
};

Alert.displayName = 'Alert';

exports.default = Alert;