'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _glamor = require('glamor');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Box = require('./Box');

var _Box2 = _interopRequireDefault(_Box);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var majorScale = _theme2.default.majorScale,
    colors = _theme2.default.colors,
    rawColors = _theme2.default.rawColors;


var intentStateStyle = function intentStateStyle(intentState) {
  return _extends({
    backgroundColor: intentState.backgroundColor,
    color: intentState.textColor
  }, intentState.border ? {
    border: intentState.border
  } : {}, intentState.boxShadow ? {
    boxShadow: intentState.boxShadow
  } : {});
};

var intentStyle = function intentStyle(intent) {
  var _extends2;

  return _extends({}, intentStateStyle(intent.default), (_extends2 = {
    '&:hover': _extends({}, intentStateStyle(intent.hover)),
    '&:focus': _extends({}, intentStateStyle(intent.focus))
  }, _defineProperty(_extends2, '&:active, &.' + _theme2.default.activeClassName, _extends({}, intentStateStyle(intent.active))), _defineProperty(_extends2, '&:disabled, &.' + _theme2.default.activeClassName + ':disabled', {
    cursor: 'default',
    backgroundColor: colors.backgroundTint2,
    color: rawColors.grey300,
    border: 'none'
  }), _extends2));
};

var getStyle = function getStyle(_ref) {
  var primary = _ref.primary,
      secondary = _ref.secondary,
      danger = _ref.danger;

  if (primary) return (0, _glamor.css)(intentStyle(_theme2.default.intent['primary']));
  if (danger) return (0, _glamor.css)(intentStyle(_theme2.default.intent['danger']));
  if (secondary) return (0, _glamor.css)(intentStyle(_theme2.default.intent['secondary'])); /* default */
  return '';
};

var baseStyles = (0, _glamor.css)({
  textTransform: 'capitalize',
  border: 0,
  fontWeight: 400,
  textDecoration: 'none',
  transition: _theme2.default.animationDuration.faster,
  transitionProperty: 'background-color, color, box-shadow, opacity',
  cursor: 'pointer',
  whiteSpace: 'nowrap',
  userSelect: 'none',
  verticalAlign: 'middle',
  '&:active, &:focus': {
    outline: 'none'
  }
});

function useControlSizes(_ref2) {
  var size = _ref2.size,
      props = _objectWithoutProperties(_ref2, ['size']);

  var sizes = _theme2.default.controlSizes[size];
  var paddingX = {
    small: majorScale(2),
    default: majorScale(3)
  };

  return _extends({
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: paddingX[size]
  }, props);
}

var parseProps = function parseProps(_ref3) {
  var className = _ref3.className,
      primary = _ref3.primary,
      secondary = _ref3.secondary,
      danger = _ref3.danger,
      props = _objectWithoutProperties(_ref3, ['className', 'primary', 'secondary', 'danger']);

  return _extends({
    className: (0, _classnames2.default)('' + baseStyles, '' + getStyle({ primary: primary, secondary: secondary, danger: danger }), className)
  }, props);
};

var Button = function Button(props) {
  return _react2.default.createElement(_Box2.default, parseProps(useControlSizes(props)));
};

Button.propTypes = _extends({}, _Box2.default.propTypes, {
  primary: _propTypes2.default.bool,
  secondary: _propTypes2.default.bool,
  danger: _propTypes2.default.bool,
  size: _propTypes2.default.oneOf(Object.keys(_theme2.default.controlSizes))
});

Button.defaultProps = {
  is: 'button',
  display: 'inline-flex',
  alignItems: 'center',
  justifyContent: 'center',
  size: 'default',
  secondary: true,
  rounded: true
};

Button.displayName = 'Button';

exports.default = Button;