'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NavigationBarTitle = exports.NavigationBarLink = exports.NavigationBar = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _glamor = require('glamor');

var _Pane = require('./Pane');

var _Pane2 = _interopRequireDefault(_Pane);

var _Text = require('./Text');

var _Text2 = _interopRequireDefault(_Text);

var _Link = require('./Link');

var _Link2 = _interopRequireDefault(_Link);

var _Box = require('./Box');

var _Box2 = _interopRequireDefault(_Box);

var _SegmentLogo = require('./SegmentLogo');

var _SegmentLogo2 = _interopRequireDefault(_SegmentLogo);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var minorScale = _theme2.default.minorScale,
    majorScale = _theme2.default.majorScale;


var NavigationBarLink = function NavigationBarLink(props) {
  return _react2.default.createElement(_Link2.default, _extends({ primary: false }, (0, _glamor.css)({
    color: _theme2.default.rawColors.blue100,
    '&:hover': {
      color: 'white',
      backgroundColor: _theme2.default.rawColors.blue800
    },
    '&:active, &.active': {
      color: 'white',
      backgroundColor: _theme2.default.rawColors.blue500
    }
  }), props));
};

NavigationBarLink.defaultProps = {
  circle: true,
  textStyle: 'body1',
  paddingX: minorScale(3),
  paddingY: minorScale(1),
  marginX: minorScale(1)
};

var NavigationBarTitle = function NavigationBarTitle(props) {
  return _react2.default.createElement(_Text2.default, props);
};

NavigationBarTitle.defaultProps = {
  is: 'h1',
  textStyle: 'display3',
  bold: true
};

// paddingTop is somewhat of a hack here, but flex will cause the truncate to fail
var NavigationBarLeftTitle = function NavigationBarLeftTitle(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, ['children']);

  return _react2.default.createElement(
    _Box2.default,
    { marginLeft: majorScale(2), truncate: true, paddingTop: '1px', paddingLeft: majorScale(2), borderLeft: true, borderColor: 'rgba(255,255,255,0.2)' },
    _react2.default.createElement(
      _Text2.default,
      _extends({ is: 'span', textStyle: 'body1' }, props),
      children
    )
  );
};

var NavigationBarLogo = function NavigationBarLogo(props) {
  return _react2.default.createElement(_SegmentLogo2.default, _extends({ marginTop: '-1px', minWidth: '106px', width: '106px' }, props));
};

var NavigationBarPane = function NavigationBarPane(props) {
  return _react2.default.createElement(_Pane2.default, _extends({ alignItems: 'center', dark: true, display: 'flex' }, props));
};

var NavigationBar = function NavigationBar(_ref2) {
  var logo = _ref2.logo,
      left = _ref2.left,
      right = _ref2.right,
      height = _ref2.height,
      children = _ref2.children,
      props = _objectWithoutProperties(_ref2, ['logo', 'left', 'right', 'height', 'children']);

  var child = void 0;
  if (typeof children === 'string') {
    child = _react2.default.createElement(
      NavigationBarTitle,
      null,
      children
    );
  } else {
    child = children;
  }

  var leftChild = void 0;
  if (typeof left === 'string') {
    leftChild = _react2.default.createElement(
      NavigationBarLeftTitle,
      null,
      left
    );
  } else {
    leftChild = left;
  }

  return _react2.default.createElement(
    NavigationBarPane,
    _extends({ height: height }, props),
    _react2.default.createElement(
      _Pane2.default,
      { width: '33%', height: '100%', padding: majorScale(2), display: 'flex' },
      logo,
      ' ',
      leftChild
    ),
    _react2.default.createElement(
      _Pane2.default,
      { flexAuto: true, textAlign: 'center' },
      child
    ),
    _react2.default.createElement(
      _Pane2.default,
      { width: '33%', textAlign: 'right', padding: minorScale(3) },
      right
    )
  );
};

NavigationBar.propTypes = {
  logo: _propTypes2.default.node,
  left: _propTypes2.default.node,
  right: _propTypes2.default.node,
  children: _propTypes2.default.oneOfType([_propTypes2.default.node, _propTypes2.default.string]),
  height: _propTypes2.default.string
};

NavigationBar.defaultProps = {
  logo: _react2.default.createElement(NavigationBarLogo, null),
  height: majorScale(7)
};

exports.NavigationBar = NavigationBar;
exports.NavigationBarLink = NavigationBarLink;
exports.NavigationBarTitle = NavigationBarTitle;