'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = gettingStartedStory;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _react3 = require('@storybook/react');

var _components = require('../components');

var _Content = require('./Content');

var _Content2 = _interopRequireDefault(_Content);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var minorScale = _components.theme.minorScale,
    majorScale = _components.theme.majorScale;
function gettingStartedStory(module) {
  (0, _react3.storiesOf)('Getting Started', module).add('Welcome to the React UI Library', function () {
    return _react2.default.createElement(
      _components.App,
      null,
      _react2.default.createElement(
        _components.Pane,
        { flexAuto: true, white: true, padding: majorScale(10), clearfix: true },
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n# Welcome to the React UI Library for segment\n> Presentational React Components with a coherent API for developers\n\nThe React UI Library is a set of presentational UI components build in React based on Segment styles.\n\n* Uses the Segment Design System\n* Powerful component API\n* Dedicated UI engineering workflow\n* Documentation with React Storybook\n* Powerful prototyping tool\n\n## Installing the library in your project\n\nThe library is a single dependency with all of the UI. Install with yarn or npm.\n\n```\n$ yarn add @segment/react-ui-library\n```\n\nUsing `npm`:\n\n```\n$ npm install --save @segment/react-ui-library\n```\n\n## Using your first component\n\nYou can import all of the components straight out of the UI Library.\nHere is a full working example (assuming you have a ES6, React environment).\n\n'
        ),
        _react2.default.createElement(
          _components.CodeBlock,
          { language: 'jsx' },
          'import React from \'react\'\nimport ReactDOM from \'react-dom\'\nimport {\n  Button\n} from \'@segment/react-ui-library\'\n\nconst MyButton = () => <Button primary>I am using the UI Library!</Button>\n\nReactDOM.render(<MyButton />, document.getElementById(\'root\'))\n'
        ),
        _react2.default.createElement(
          _components.Pane,
          { tint: true, padding: majorScale(2), marginTop: majorScale(2), border: true },
          _react2.default.createElement(
            _components.Button,
            { primary: true },
            'I am using the UI Library!'
          )
        ),
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n\n## Documentation\n\nReact Storybook is used for documentation (the thing you are currently reading).\nThe `usage` tab for each component is used to describe how the component is used, and potentially the properties.\n\nTabs under a component other than usage will contain examples of the component being used.\nIf you are curious to know how that is build look inside of `react-ui-library/src/stories/component-story.js`.\nYou can do this in Github, or clone the React UI Library\n'
        )
      )
    );
  }).add('Using the spacing system', function () {
    return _react2.default.createElement(
      _components.App,
      null,
      _react2.default.createElement(
        _components.Pane,
        { flexAuto: true, white: true, padding: majorScale(10), clearfix: true },
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n# Using the spacing system\n\nThe React UI Library uses a major scale based on 8px \u2014 and a minor scale based on 4px.\nThat means that everything should be a multiple of 8px or 4px.\n\n## Importing the spacing scales\n\nFrom v1.0.4 forward you can import the spacing scales directly from the library:\n'
        ),
        _react2.default.createElement(
          _components.CodeBlock,
          { language: 'jsx' },
          'import React from \'react\'\nimport ReactDOM from \'react-dom\'\nimport {\n  Pane,\n  Button,\n  minorScale, // <= importing the minor scale here\n  majorScale // <= importing the major scale here\n} from \'@segment/react-ui-library\'\n\nconst UsingSpacing = () =>\n  <Pane tint padding={majorScale(2)} marginTop={majorScale(2)} border>\n    <Button primary marginRight={minorScale(3)}>Primary</Button>\n    <Button>Secondary</Button>\n  </Pane>\n\nReactDOM.render(<UsingSpacing />, document.getElementById(\'root\'))\n'
        ),
        _react2.default.createElement(
          _components.Text,
          { textStyle: 'display4', marginTop: majorScale(2) },
          'Result:'
        ),
        _react2.default.createElement(
          _components.Pane,
          { tint: true, padding: majorScale(2), marginTop: majorScale(2), border: true },
          _react2.default.createElement(
            _components.Button,
            { primary: true, marginRight: minorScale(3) },
            'Primary'
          ),
          _react2.default.createElement(
            _components.Button,
            null,
            'Secondary'
          )
        ),
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n\n## How does majorScale and minorScale work?\n\nThe best way to understand the scales is to take a look at how they are implemented:\n\n'
        ),
        _react2.default.createElement(
          _components.CodeBlock,
          { language: 'javascript' },
          'const majorScale = x => `${x * 8}px`\nconst minorScale = x => `${x * 4}px`\n\nmajorScale(1) // => \'8px\'\nmajorScale(2) // => \'16px\'\nmajorScale(3) // => \'24px\'\nmajorScale(4) // => \'32px\'\nmajorScale(5) // => \'40px\'\n\nminorScale(1) // => \'4px\'\nminorScale(3) // => \'12px\'\nminorScale(5) // => \'20px\'\n'
        ),
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n\n\n\n\n## When to use majorScale vs. minorScale\n\nUse majorScale first. If something doesn\'t work try the minorScale.\n\n* minorScale is allowed for dimensions and spacing of icons\n* minorScale is allowed for spacing of small text\n\n## Upgrading from v0 to v1\n\nHere is a mapping from the old implicit spacing system to new explicit spacing system.\n\n'
        ),
        _react2.default.createElement(
          _components.CodeBlock,
          { language: 'javascript' },
          'const space = [\n  \'0\',    //  0\n  \'4px\',  // 1: minorScale(1)\n  \'8px\',  // 2: majorScale(1)\n  \'12px\', // 3: minorScale(2)\n  \'16px\', // 4: majorScale(2)\n  \'24px\', // 5: majorScale(3)\n  \'32px\', // 6: majorScale(4)\n  \'40px\', // 7: majorScale(5)\n  \'48px\', // 8: majorScale(6)\n  \'64px\', // 9: majorScale(8)\n  \'80px\'  // 10: majorScale(10)\n]\n'
        )
      )
    );
  });
}