'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = themeStory;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _react3 = require('@storybook/react');

var _color = require('color');

var _color2 = _interopRequireDefault(_color);

var _components = require('../components');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var majorScale = _components.theme.majorScale;

var mjs = majorScale;

var pickColor = function pickColor(color) {
  return Object.keys(_components.theme.rawColors).filter(function (key) {
    return key.indexOf(color) > -1;
  }).map(function (key) {
    return {
      key: key,
      val: _components.theme.rawColors[key]
    };
  });
};

var groupedColors = {
  green: pickColor('green'),
  blue: pickColor('blue'),
  grey: pickColor('grey'),
  pink: pickColor('pink'),
  peach: pickColor('peach')
};

var ColorSwatchDetails = function ColorSwatchDetails(_ref) {
  var color = _ref.color;
  return _react2.default.createElement(
    _components.Pane,
    { width: '160px', height: '160px', padding: mjs(2) },
    _react2.default.createElement(
      _components.Body1,
      null,
      (0, _color2.default)(color).hsl().round().string()
    ),
    _react2.default.createElement(
      _components.Body1,
      null,
      (0, _color2.default)(color).rgb().round().string()
    ),
    _react2.default.createElement(
      _components.Body1,
      null,
      'Hue: ',
      (0, _color2.default)(color).hsl().round().hue()
    )
  );
};

function findRawColor(color) {
  return Object.keys(_components.theme.rawColors).find(function (key) {
    return _components.theme.rawColors[key] === color;
  });
}

var ColorSwatch = function ColorSwatch(_ref2) {
  var name = _ref2.name,
      color = _ref2.color,
      showRaw = _ref2.showRaw;
  return _react2.default.createElement(
    _components.Pane,
    { style: { float: 'left' }, marginRight: mjs(2), marginBottom: mjs(2), textAlign: 'center' },
    _react2.default.createElement(
      _components.Popover,
      { useArrow: true, content: _react2.default.createElement(ColorSwatchDetails, { color: color }) },
      _react2.default.createElement(_components.Pane, { display: 'inline-block', circle: true, width: '64px', height: '64px', style: { backgroundColor: color } })
    ),
    _react2.default.createElement(
      _components.Body1,
      null,
      name
    ),
    _react2.default.createElement(
      _components.Body2,
      null,
      showRaw && findRawColor(color)
    ),
    _react2.default.createElement(
      _components.Body2,
      { textColor: 'muted' },
      color
    )
  );
};

var Colors = function Colors(_ref3) {
  var colors = _ref3.colors,
      title = _ref3.title,
      hue = _ref3.hue;
  return _react2.default.createElement(
    _components.Pane,
    { clearfix: true, marginBottom: mjs(4) },
    _react2.default.createElement(
      _components.Display3,
      { marginY: mjs(2) },
      title,
      ' ',
      _react2.default.createElement(
        _components.Text,
        { is: 'span', textColor: 'muted' },
        '\xB7 hue: ',
        hue
      )
    ),
    _react2.default.createElement(
      _components.Pane,
      null,
      colors.map(function (obj) {
        return _react2.default.createElement(ColorSwatch, { key: obj.key, name: obj.key, color: obj.val });
      })
    )
  );
};

var TextColors = function TextColors() {
  return _react2.default.createElement(
    _components.Pane,
    { marginBottom: majorScale(8), clearfix: true },
    _react2.default.createElement(
      _components.Display1,
      null,
      'Text Colors'
    ),
    _react2.default.createElement(
      _components.Body1,
      null,
      'The following colors are available as text colors. Accessible on ',
      _react2.default.createElement(
        _components.Code,
        null,
        'theme.textColors[color]'
      ),
      '.'
    ),
    _react2.default.createElement(
      _components.Pane,
      { marginTop: mjs(3), clearfix: true },
      Object.keys(_components.theme.textColors).map(function (key) {
        return _react2.default.createElement(ColorSwatch, { key: key, name: key, color: _components.theme.textColors[key], showRaw: true });
      })
    )
  );
};

var FunctionalColors = function FunctionalColors() {
  return _react2.default.createElement(
    _components.Pane,
    { marginBottom: majorScale(8), clearfix: true },
    _react2.default.createElement(
      _components.Display1,
      null,
      'Functional Colors'
    ),
    _react2.default.createElement(
      _components.Body1,
      null,
      'You should try to use functional colors instead of raw colors. Accessible on ',
      _react2.default.createElement(
        _components.Code,
        null,
        'theme.colors[color]'
      ),
      '.'
    ),
    _react2.default.createElement(
      _components.Pane,
      { marginTop: mjs(3), clearfix: true },
      Object.keys(_components.theme.colors).map(function (key) {
        return _react2.default.createElement(ColorSwatch, { key: key, name: key, color: _components.theme.colors[key], showRaw: true });
      })
    )
  );
};

var RawColors = function RawColors() {
  return _react2.default.createElement(
    _components.Pane,
    { marginBottom: majorScale(8), clearfix: true },
    _react2.default.createElement(
      _components.Display1,
      null,
      'Raw Colors'
    ),
    _react2.default.createElement(
      _components.Body1,
      null,
      'These are the underlying colors that support the functional colors. Accessible on ',
      _react2.default.createElement(
        _components.Code,
        null,
        'theme.rawColors[color]'
      ),
      '.'
    ),
    _react2.default.createElement(Colors, { colors: groupedColors.green, title: 'Green', hue: '151' }),
    _react2.default.createElement(Colors, { colors: groupedColors.blue, title: 'Blue', hue: '209' }),
    _react2.default.createElement(Colors, { colors: groupedColors.grey, title: 'Grey', hue: '209' }),
    _react2.default.createElement(Colors, { colors: groupedColors.pink, title: 'Pink', hue: '329' }),
    _react2.default.createElement(Colors, { colors: groupedColors.peach, title: 'Peach', hue: '27' })
  );
};

function themeStory(module) {
  (0, _react3.storiesOf)('Design / Theme', module).add('colors', function () {
    return _react2.default.createElement(
      _components.App,
      null,
      _react2.default.createElement(
        _components.Pane,
        { flexAuto: true, white: true, padding: majorScale(10), clearfix: true },
        _react2.default.createElement(FunctionalColors, null),
        _react2.default.createElement(TextColors, null),
        _react2.default.createElement(RawColors, null)
      )
    );
  });
}